@@ -10,7 +10,7 @@ use App::UpdateCPANfile::Change;
 use Module::CoreList;
 use List::Util qw(shuffle);
 
-our $VERSION = "1.1.0";
+our $VERSION = "1.1.1";
 
 sub new {
     my ($class, $path, $snapshot_path, $options) = @_;
@@ -167,7 +167,10 @@ sub _apply_filter {
     }
 
     if (my $limit = $self->options->{limit}) {
-        $changeset = [ splice(@$changeset, 0, $limit) ];
+        my $limited_changeset = [ splice(@$changeset, 0, $limit) ];
+        my $is_changed_path = { map { $_->path => 1 } @$limited_changeset };
+        my $associated_changeset = [ grep { $is_changed_path->{ $_->path } } @$changeset ];
+        $changeset = [ @$limited_changeset, @$associated_changeset ];
     }
     return $changeset;
 }
